@@ -7,7 +7,13 @@ import logging
 
 import shutil
 
-from torch.utils.data import TensorDataset, DataLoader, RandomSampler, SequentialSampler
+from torch.utils.data import (
+    Dataset,
+    TensorDataset,
+    DataLoader,
+    RandomSampler,
+    SequentialSampler,
+)
 from torch.utils.data.distributed import DistributedSampler
 
 from transformers import AutoTokenizer
@@ -306,7 +312,8 @@ class MultiLabelTextProcessor(TextProcessor):
                 # create one hot vector of labels
                 label_list = self.get_labels()
                 labels = [0] * len(label_list)
-                labels[label_list.index(row[label_col])] = 1
+                # cast with string in case labels are integers
+                labels[label_list.index(str(row[label_col]))] = 1
                 return labels
 
         """Creates examples for the training and dev sets."""
@@ -332,6 +339,21 @@ class MultiLabelTextProcessor(TextProcessor):
             )
 
 
+class LRFinderDataset(Dataset):
+    def __init__(self, data_dir, filename, text_col, label_col):
+        super().__init__()
+        self.text_col = text_col
+        self.label_col = label_col
+
+        self.data = pd.read_csv(os.path.join(data_dir, filename))
+
+    def __getitem__(self, idx):
+        return self.data.loc[idx, self.text_col], self.data.loc[idx, self.label_col]
+
+    def __len__(self):
+        return self.data.shape[0]
+
+
 class BertDataBunch(object):
     def __init__(
         self,
@@ -353,6 +375,7 @@ class BertDataBunch(object):
         logger=None,
         clear_cache=False,
         no_cache=False,
+        custom_sampler=None,
     ):
 
         # just in case someone passes string instead of Path
@@ -382,6 +405,7 @@ class BertDataBunch(object):
         self.no_cache = no_cache
         self.model_type = model_type
         self.output_mode = "classification"
+        self.custom_sampler = custom_sampler
         if logger is None:
             logger = logging.getLogger()
         self.logger = logger
@@ -422,7 +446,12 @@ class BertDataBunch(object):
             )
 
             self.train_batch_size = self.batch_size_per_gpu * max(1, self.n_gpu)
-            train_sampler = RandomSampler(train_dataset)
+
+            if self.custom_sampler is not None:
+                train_sampler = self.custom_sampler
+            else:
+                train_sampler = RandomSampler(train_dataset)
+
             self.train_dl = DataLoader(
                 train_dataset, sampler=train_sampler, batch_size=self.train_batch_size
             )
